@@ -8,7 +8,7 @@ package ISG::ParseConfig;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = 1.6;
+$VERSION = 1.7;
 
 sub new($$)
 {
@@ -372,7 +372,7 @@ sub _parse_table($$)
                 return 0;
             };
         }
-        if (defined $g->{_sub}){
+        if (defined $gc->{_sub}){
                 my $error = &{$gc->{_sub}}($c);
                 if (defined $error) {
                         $self->_make_error($error);
@@ -565,23 +565,33 @@ sub _genpod($$$){
 		    " I<(mandatory setting)>" : ""; 
 	    push @{$doc}, "=item B<$var>".$mandatory;
 	    push @{$doc}, $tree->{$var}{_doc} if $tree->{$var}{_doc} ;
+	    push @{$doc}, "Example: $var = $tree->{$var}{_example}"
+		    if ($tree->{$var}{_example})
 	}
 	push @{$doc}, "=back";
     }
 
     if ($tree->{_text}){
 	push @{$doc}, ($tree->{_text}{_doc} or "Unspecified Text content");
+	if ($tree->{_text}{_example}){
+	    my $ex = $tree->{_text}{_example};
+	    chomp $ex;
+	    $ex = map {" $_"} split /\n/, $ex;
+	    push @{$doc}, "Example:\n\n$ex\n";
+	}
     }
 
     if ($tree->{_table}){
-	push @{$doc}, ($tree->{_table}{_doc} or 
+	push @{$doc}, ($tree->{_table}{_doc} or
 		       "This section can contain a table ".
 		       "with the following structure:" );
 	push @{$doc}, "=over";
 	for (my $i=0;$i < $tree->{_table}{_columns}; $i++){
 	    push @{$doc}, "=item column $i";
-	    push @{$doc}, ($tree->{_table}{$i}{_doc} or 
+	    push @{$doc}, ($tree->{_table}{$i}{_doc} or
 			   "Unspecific Content");
+	    push @{$doc}, "Example: $tree->{_table}{$i}{_example}"
+		    if ($tree->{_table}{$i}{_example})
 	}
 	push @{$doc}, "=back";
     }
@@ -624,9 +634,15 @@ sub _gentmpl($$$@){
     my @start = @_;
     if (scalar @start ) {
 	my $section = shift @start;
-	push @{$doc},
-	    ($level > 0) ?
-		("+" x $level)."$section" : "*** $section ***";
+	my $secex ='';
+	my $prefix = '';
+	$prefix = "# " unless $tree->{_mandatory} and 
+		    grep {$_ eq $section} @{$tree->{_mandatory}};
+	if ($tree->{$section}{_example}) {
+	    $secex = " #  ( ex. $tree->{$section}{_example} )";
+	}
+ 	push @{$doc}, $prefix.
+	    (($level > 0) ? ("+" x $level)."$section" : "*** $section ***").$secex;
 	my $match;
 	foreach my $s (@{$tree->{_sections}}){
 	    if ($s =~ m|^/.+/$| and $section =~ /$s/ or $s eq $section) {
@@ -640,32 +656,44 @@ sub _gentmpl($$$@){
     } else {
 	if ($tree->{_vars}){
 	    foreach my $var (@{$tree->{_vars}}){
-		my $opt = ( $tree->{_mandatory} and 
-			    grep {$_ eq $var} @{$tree->{_mandatory}} ) ?
-				"":"#"; 
-		push @{$doc}, "$opt$var=";
+		push @{$doc}, "# $var = ". 
+		    ($tree->{$var}{_example} || ' * no example *');
+		next unless $tree->{_mandatory} and 
+		    grep {$_ eq $var} @{$tree->{_mandatory}};
+		push @{$doc}, "$var=";
 	    }
 	}
-	
+
 	if ($tree->{_text}){
-	    push @{$doc}, "<text>";
-	}
-	
-	if ($tree->{_table}){
-	    my $table = "\n# table\n# ";
-	    for (my $i=0;$i < $tree->{_table}{_columns}; $i++){
-		$table .= "  C$i";
+	    if ($tree->{_text}{_example}){
+		my $ex = $tree->{_text}{_example};
+		chomp $ex;
+		$ex = map {"# $_"} split /\n/, $ex;
+		push @{$doc}, "$ex\n";
 	    }
-	    push @{$doc}, $table;
+	}
+	if ($tree->{_table}){
+	    my $table = "# table\n#";
+	    for (my $i=0;$i < $tree->{_table}{_columns}; $i++){
+		$table .= ' "'.($tree->{_table}{$i}{_example} || "C$i").'"';
+	    }
+ 	    push @{$doc}, $table;
 	}
 	if ($tree->{_sections}){
 	    foreach my $section (@{$tree->{_sections}}){
 		my $opt = ( $tree->{_mandatory} and 
-			    grep {$_ eq $section} @{$tree->{_mandatory}} ) ?
+		 	    grep {$_ eq $section} @{$tree->{_mandatory}} ) ?
 				"":"\n# optional section\n"; 
-		push @{$doc}, ($level > 0) ? 
-		    $opt.("+" x $level)."$section" :
-			"$opt*** $section ***";
+		my $prefix = '';
+		$prefix = "# " unless $tree->{_mandatory} and 
+		    grep {$_ eq $section} @{$tree->{_mandatory}};
+		my $secex ="";
+		if ($section =~ m|^/.+/$| && $tree->{$section}{_example}) {
+		    $secex = " #  ( ex. $tree->{$section}{_example} )";
+		}
+		push @{$doc}, $prefix.
+		    (($level > 0) ? ("+" x $level)."$section" : "*** $section ***").
+			$secex;
 		_gentmpl ($tree->{$section},$level+1,$doc,@start)
 		    unless $tree eq $tree->{$section};
 	    }
@@ -821,6 +849,10 @@ string as content.
 
 Describtion of the variable.
 
+=item _example
+
+A one line example for the content of this variable.
+
 =back
 
 =head3 Special Table Keys
@@ -846,6 +878,10 @@ they work analog to the description in the previous section.
 
 describes the content of the column.
 
+=item _example
+
+example for the content of this column
+
 =back
 
 =head3 Special Text Keys
@@ -870,6 +906,10 @@ they work analog to the description in the previous section.
 
 Ditto.
 
+=item _example
+
+Potential multi line example for the content of this text section
+
 =back
 
 =head2 Configuration Syntax
@@ -937,27 +977,25 @@ The data is interpreted as one or more columns separated by spaces.
       _sections => [ "/$RE_IP/" ],
       dns       => {
          _doc => "address of the dns server",
+         _example => "ns1.oetiker.xs",
          _re => $RE_HOST,
          _re_error =>
             'dns must be an host name or ip address',
          },
       "/$RE_IP/" => {
          _doc    => "Ip Adress",
-         _vars   => [ 'dns', 'netmask', 'gateway' ],
-         dns     => {
-	    _doc => "address of the dns server",
-            _re => $RE_HOST,
-            _re_error =>
-               'dns must be an host name or ip address'
-            },
+         _example => '10.2.3.2',
+         _vars   => [ 'netmask', 'gateway' ],
          netmask => {
 	    _doc => "Netmask",
+	    _example => "255.255.255.0",
             _re => $RE_IP,
             _re_error =>
                'netmask must be a dotted ip address'
             },
          gateway => {
 	    _doc => "Default Gateway address in IP notation",
+	    _example => "10.22.12.1",
             _re => $RE_IP,
             _re_error =>
                'gateway must be a dotted ip address' },
@@ -971,16 +1009,22 @@ The data is interpreted as one or more columns separated by spaces.
          _columns => 3,
          0 => {
             _doc => "Ethernet Address",
+            _example => "0:3:3:d:a:3:dd:a:cd",
             _re => $RE_MAC,
             _re_error =>
                'first column must be an ethernet mac address',
             },
          1 => {
             _doc => "IP Address",
+            _example => "10.11.23.1",
             _re => $RE_IP,
             _re_error =>
                'second column must be a dotted ip address',
             },
+         2 => {
+            _doc => "Host Name",
+            _example => "tardis",
+             },
          },
       },
    });
@@ -1072,6 +1116,7 @@ S<Tobias Oetiker E<lt>oetiker@ee.ethz.chE<gt>>
  2002-03-12 ds 1.5 Implemented @define, make makepod return a string and not an array
  2002-08-28 to     Added maketmpl methode
  2002-10-10 ds 1.6 More verbatim _text sections
+ 2004-02-09 to 1.7 Added _example propperty for pod and template generation
 
 =cut
 
