@@ -258,14 +258,16 @@ sub pingone {
 
 	my @times;
 
-	open(P, "$cmd 2>&1 |") or croak("fork: $!");
-
+	open(P, "$cmd 2>&1 |") or carp("fork: $!");
+	
 	# what should we do with error messages?
+	my $echoret;
 	while (<P>) {
+		$echoret .= $_;
 		/^Elapsed time: (\d+\.\d+) seconds/ and push @times, $1;
 	}
 	close P;
-	
+	carp "WARNING: $cmd was not happy: $echoret\n" if $?;
 	# carp("Got @times") if $self->debug;
 	return sort { $a <=> $b } @times;
 }
