@@ -22,9 +22,10 @@ Measures HTTP roundtrip times (web servers and caches) for SmokePing.
 
  + PROBE_CONF
  url = / 
- ignore-cache = yes
- force-revalidate = no
+ ignore_cache = yes
+ revalidate_data = no
  port = 80 # default value anyway
+ timeout = 50 # default is 10s
 
 =head1 DESCRIPTION
 
@@ -58,6 +59,12 @@ Enabled if the value is anything other than 'no' or '0'.
 The echoping(1) "-a" option: force the proxy to revalidate data with original 
 server. Enabled if the value is anything other than 'no' or '0'.
 
+=item timeout
+
+The echoping(1) "-t" option: Number  of  seconds  to  wait a reply before giving up. For TCP,
+this is the maximum number of seconds for the  whole  connection
+(setup and data exchange).
+
 =back
 
 =head1 AUTHOR
@@ -104,6 +111,11 @@ sub proto_args {
 
 	my @args = ("-h", $url);
 
+	# -t : timeout
+	my $timeout = $target->{vars}{timeout};
+	$timeout = $self->{properties}{timeout} 
+		unless defined $timeout;
+	push @args, "-t $timeout" if $timeout;
 
 	# -A : ignore cache
 	my $ignore = $target->{vars}{ignore_cache};
